@@ -74,6 +74,10 @@ __PACKAGE__->create_children(qw/
 
 =head2 file
 
+ $str = $self->file;
+
+Holds the path to the config file.
+
 =cut
 
 has file => (
@@ -84,6 +88,12 @@ has file => (
 
 =head2 filehandle
 
+ $glob = $self->filehandle;
+ $bool = $self->has_filehandle;
+ $self->clear_filehandle;
+
+Holds the filehande to l<file>.
+
 =cut
 
 has filehandle => (
@@ -100,6 +110,8 @@ sub _build_filehandle {
 
 =head2 root
 
+ $self = $self->root;
+
 =cut
 
 has '+root' => (
@@ -108,6 +120,8 @@ has '+root' => (
 
 =head2 parent
 
+ $self = $self->parent;
+
 =cut
 
 has '+parent' => (
@@ -128,10 +142,6 @@ List of parsed L<Net::ISC::DHCPd::Config::Option> objects.
 
 =head1 METHODS
 
-=head2 new
-
- $obj = $self->new(...);
-
 =head2 generate
 
  $config_text = $self->generate;
