@@ -6,9 +6,6 @@ Net::ISC::DHCPd::OMAPI::Actions - Common actions on OMAPI objects
 
 =head1 DESCRIPTION
 
-This module contains methods which can be called on each of the
-L<Net::ISC::DHCPd::OMAPI> subclasses.
-
 Changing object attributes will not alter the attributes on server. To do
 so, either use L<set()> directly or use L<write()> after altering attributes.
 
@@ -16,16 +13,12 @@ so, either use L<set()> directly or use L<write()> after altering attributes.
 
 use Moose::Role;
 
-my $attr_role = "Net::ISC::DHCPd::OMAPI::Meta::Attribute";
-
 =head1 ATTRIBUTES
 
 =head2 parent
 
  $omapi_obj = $self->parent;
 
-Returns the parent L<Net::ISC::DHCPd::OMAPI> object.
-
 =cut
 
 has parent => (
@@ -38,8 +31,6 @@ has parent => (
 
  $str = $self->errstr;
 
-Holds the latest error. Check this if a method returns empty list.
-
 =cut
 
 has errstr => (
@@ -119,40 +110,40 @@ attribute with action "modify" on update.
 sub write {
     my $self = shift;
     my @attr = @_;
-    my $new = 0;
+    my $new  = 1;
     my(@cmd, @out);
 
     # check for existence
     @out = $self->_open;
 
-    if(grep { /not found/i } @out) {
-        $new = 1;
+    if($out[-1] =~ /(\S+)\s=\s(\S+)/g) {
+        $new = 0;
     }
 
     if(@attr == 0) {
+        my $attr_role = "Net::ISC::DHCPd::OMAPI::Meta::Attribute";
         for my $attr ($self->meta->get_all_attributes) {
-            my $name = $attr->name;
-
             next if(!$attr->does($attr_role));
-            next if(!$self->${ \"has_$name" });
-            next if(!$attr->has_action('modify'));
-
-            push @attr, $attr;
+            next if(!$attr->has_action('modify') and !$new);
+            next if($attr->has_action('modify') and !$new);
+            push @attr, $attr->name;
         }
     }
 
-    @cmd = map { $self->_set_cmd($_) } @attr or return;
+    for my $name (@attr) {
+        my $key = $name;
+        $key =~ s/_/-/g;
+        push @cmd, 'set %s = %s', $key, $self->$name;
+    }
 
     # set attributes
     @out = $self->_cmd(@cmd);
 
-    # update or create
-    @out = $self->_cmd( $new ? "create" : "update" ) or return;
+    # need to test @out
+    # ...
 
-    if(grep { /not found/ } @out) {
-        $self->errstr("not found");
-        return;
-    }
+    # update or create
+    $self->_cmd( $new ? "create" : "update" ) or return;
 
     return $new ? +1 : -1;
 }
@@ -184,7 +175,7 @@ sub unset {
         $self->${ \"clear_$_" } for(@attr);
     }
 
-    return 1;
+    return;
 }
 
 around unset => \&_around;
@@ -193,33 +184,24 @@ around unset => \&_around;
 
  $bool = $self->remove;
 
-This method will remove the object from the server.
-
 =cut
 
 sub remove {
     my $self = shift;
+    my $pk   = $self->primary;
     my @out;
 
-    @out = $self->_open;
-    @out = $self->_cmd('remove');
-
-    if(grep { /not implemented/i } @out) {
-        $self->errstr('not implemented');
-        return;
-    }
-    if(grep { /not found/i } @out) {
-        $self->errstr('not found');
-        return;
-    }
+    @out = $self->_cmd(
+               sprintf("set %s = %s", $pk, $self->$pk),
+               "remove",
+           );
 
     for my $attr ($self->meta->get_all_attributes) {
-        next unless($attr->does($attr_role));
-        my $clearer = 'clear_' .$attr->name;
-        $self->$clearer;
+        next unless($attr->has_value('omapi'));
+        $self->${ \"clear_" .$attr->name };
     }
 
-    return 1;
+    return;
 }
 
 around remove => \&_around;
@@ -231,41 +213,32 @@ sub _open {
 
     for my $name ($self->meta->get_attribute_list) {
         my $attr = $self->meta->get_attribute($name);
+        my $key = $name;
+        my $format;
 
         next unless($attr->does("Net::ISC::DHCPd::OMAPI::Meta::Attribute"));
         next unless($attr->has_action("lookup"));
         next unless($self->${ \"has_$name" });
 
-        push @cmd, $self->_set_cmd($attr);
+        $key =~ s/_/-/g;
+
+        $format = $attr->type_constraint->equals('Str') ? 'set %s = "%s"'
+                :                                         'set %s = %s';
+
+        push @cmd, sprintf $format, $key, $self->$name;
     }
 
     return $self->_cmd(@cmd, "open");
 }
 
-sub _set_cmd {
-    my $self = shift;
-    my $attr = shift;
-    my $name = $attr->name;
-    my $key = $name;
-    my $format;
-
-    $key =~ s/_/-/g;
-    $format = $attr->type_constraint->equals('Str') ? 'set %s = "%s"'
-            :                                         'set %s = %s';
-
-    return sprintf $format, $key, $self->${ \"raw_$name" };
-}
-
 sub _around {
     my $next = shift;
     my $self = shift;
     my $type = lc +(ref($self) =~ /::(\w+)$/)[0];
     my(@out, @ret);
 
-    $self->errstr("");
-
     @out = $self->_cmd("new $type") or return 0;
-    @ret = $self->$next(@_);
+    @ret = $self->$next(@_)         or return 0;
     @out = $self->_cmd('close')     or return 0;
 
     return @ret == 1 ? $ret[0] : @ret;
@@ -279,6 +252,8 @@ sub _cmd {
     my @cmd  = @_;
     my(@buffer, $head);
 
+    $self->errstr("");
+
     for my $cmd (@cmd) {
         my $tmp = $self->parent->_cmd($cmd);
         last unless(defined $tmp);
